( cd usr/bin ; rm -rf uuidcdef )
( cd usr/bin ; ln -sf uuidgen uuidcdef )
( cd usr/lib/xplc-0.3.13 ; rm -rf libxplc.so )
( cd usr/lib/xplc-0.3.13 ; ln -sf ../libxplc.so.0.3.13 libxplc.so )
( cd usr/lib/xplc-0.3.13 ; rm -rf libxplc_s.a )
( cd usr/lib/xplc-0.3.13 ; ln -sf libxplc.a libxplc_s.a )
( cd usr/man/man1 ; rm -rf uuidcdef.1 )
( cd usr/man/man1 ; ln -sf uuidgen.1 uuidcdef.1 )
